California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 002 - STANDARDS FOR CONFINING FARM ANIMALS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1301462 | YES ON PROP. 2-CALIFORNIANS FOR HUMANE FARMS, A COALITION OF THE HUMANE SOCIETY OF THE US, FARM SANCTUARY, OTHER ANIMAL PROTECTION GROUPS, FAMILY FARMERS, VETERINARIANS & PUBLIC HEALTH PROFESSIONALS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1301370 | CALIFORNIANS FOR SAFE FOOD, A COALITION OF PUBLIC HEALTH AND FOOD SAFETY EXPERTS, LABOR UNIONS, CONSUMERS, FAMILY FARMERS AND VETERINARIANS. NO ON PROPOSITION 2 | OPPOSE